==> GameboyVM-Project-0.06.zip: win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by GBEmu.rc
//
#define VS_STRING                       1
#define IDS_APP_TITLE                   1
#define IDS_TITLE                       1
#define IDS_UNKNOW_OPCODE               2
#define IDS_UNDEFINE_OPCODE             2
#define IDS_DISASSEMBLING               3
#define IDS_DEBUGGER_TITLE              5
#define IDS_SHOW_FPS                    6
#define IDS_FILTER_ROM                  7
#define IDS_UNSUPPORTED_MMC             8
#define IDS_UNSUPPORTED_GBC             9
#define IDS_INITIALIZE_REGISTERS        10
#define IDS_INITIALIZE_MEMORY           11
#define IDS_FILTER_ALL                  12
#define IDS_UNKNOW_CB_OPCODE            13
#define IDS_UNSUPPORTED_SIZE            14
#define IDS_UNSUPPORTED_ROM_SIZE        14
#define IDS_MEMORY_ALLOC_ERROR          15
#define IDS_NOT_ZIP_FILE                16
#define IDS_ERROR_MAIN_THREAD           17
#define IDD_GBEMU_DIALOG                102
#define IDC_PAINT_CURSOR                104
#define IDR_MAINFRAME                   128
#define IDR_MENU                        129
#define IDC_CURSOR1                     130
#define IDD_KEY_DIALOG                  130
#define IDD_ABOUT_DIALOG                131
#define IDD_TILES_DIALOG                133
#define IDD_MAPS_DIALOG                 135
#define IDD_MEMORY_DIALOG               137
#define IDD_DISASM_DIALOG               139
#define IDD_MEMEDIT_DIALOG              141
#define IDD_OBJ_DIALOG                  141
#define IDR_ACCELERATOR                 145
#define IDC_CURSOR                      149
#define IDD_ABOUT_DIALOG1               150
#define IDD_DISASM_DIALOG1              151
#define IDR_MENU1                       152
#define IDD_DMA_DIALOG                  153
#define IDC_MAP_ADR1                    1000
#define IDC_MAP_ADR2                    1001
#define IDC_KEY_A                       1001
#define IDC_MEMORY_LIST                 1002
#define IDC_KEY_B                       1002
#define IDC_ADR_CMB                     1003
#define IDC_KEY_S                       1003
#define IDC_DUMP                        1004
#define IDC_KEY_E                       1004
#define IDC_EDIT_ADR                    1005
#define IDC_KEY_U                       1005
#define IDC_KEY_D                       1006
#define IDC_BANK                        1006
#define IDC_GO                          1007
#define IDC_KEY_L                       1007
#define IDC_KEY_R                       1008
#define IDC_DISASM_LIST                 1012
#define IDC_CMD_EDIT                    1013
#define IDC_STACK_LIST                  1014
#define IDC_REG_AF                      1015
#define IDC_REG_BC                      1016
#define IDC_REG_DE                      1017
#define IDC_REG_HL                      1018
#define IDC_REG_SP                      1019
#define IDC_REG_PC                      1020
#define IDC_FLAG_Z                      1021
#define IDC_FLAG_N                      1022
#define IDC_FLAG_H                      1023
#define IDC_FLAG_C                      1024
#define IDC_FLAG_IME                    1025
#define IDC_BREAK_POINT1                1029
#define IDC_BREAK_POINT2                1030
#define IDC_NEXT                        1031
#define IDC_EDIT2                       1032
#define IDC_EDIT_GOTO                   1032
#define IDC_BREAK_POINT3                1033
#define IDC_CHECK2                      1034
#define IDC_INTERRUPT1                  1034
#define IDC_CHECK_OBJ1                  1034
#define IDC_CHECK3                      1035
#define IDC_INTERRUPT2                  1035
#define IDC_CHECK_OBJ2                  1035
#define IDC_CHECK4                      1036
#define IDC_INTERRUPT3                  1036
#define IDC_CHECK_OBJ4                  1036
#define IDC_CHECK5                      1037
#define IDC_INTERRUPT4                  1037
#define IDC_CHECK_OBJ3                  1037
#define IDC_CHECK6                      1038
#define IDC_INTERRUPT5                  1038
#define IDC_CHECK7                      1041
#define IDC_CHECK_BREAK                 1041
#define IDC_BUTTON4                     1043
#define IDC_RUN                         1043
#define IDC_RESET                       1044
#define IDC_STOP                        1045
#define IDC_GOTO                        1050
#define IDC_URL                         1051
#define IDC_OBJ_NO                      1054
#define IDC_OBJ_POSITION                1055
#define IDC_OBJ_RETURN                  1056
#define IDC_OBJ_TILENO                  1057
#define IDC_OBJ_NEXT                    1058
#define IDC_OBJ_SIZE                    1059
#define IDC_GROUP_LCDC                  1061
#define IDC_GROUP_BGP                   1062
#define IDC_MEM_SCROLLBAR               1063
#define IDC_Update                      1064
#define ID_CMD_OK                       1065
#define IDC_GROUP_STATUS                1066
#define IDC_TILE_ADDRESS                1068
#define IDC_STATIC_ADDRESS              1069
#define IDC_TILE_NO                     1070
#define IDC_STATIC_NO                   1071
#define IDC_MODE_FLAG                   1072
#define IDC_STATIC_BANK                 1073
#define IDC_SCROLLBAR_DMA               1074
#define IDC_DMA_ADDRESS                 1075
#define IDC_BUTTON_GO                   1076
#define IDC_CHECK_EDIT                  1080
#define IDC_IMAGE_CHAR                  1081
#define IDC_IMAGE_TILES                 1082
#define IDC_BUTTON_SAVE                 1094
#define IDC_EDIT_OFFSET                 1095
#define IDC_BUTTON_RESET                1096
#define IDC_BUTTON_WRITE                1100
#define IDC_SCROLLBAR_BANK              1101
#define IDC_PALETTE0                    1102
#define IDC_EDIT_BANK                   1103
#define IDC_BUTTON_SAVEBIN              1104
#define IDC_BUTTON_LOADBIN              1105
#define IDC_PALETTE1                    1106
#define IDC_PALETTE2                    1107
#define IDC_PALETTE3                    1108
#define IDC_STATIC_OFFSET               1109
#define ID_MENU_OPEN                    32771
#define ID_MENU_EXIT                    32772
#define ID_MENU_ABOUT                   32773
#define ID_MENU_RESET                   32774
#define ID_SHOW_FPS                     32775
#define ID_SHOW_MEMORY                  32776
#define ID_PRIORITY_NORMAL              32779
#define ID_PRIORITY_ABOVE               32781
#define ID_PRIORITY_BELOW               32782
#define ID_PRIORITY_HIGHEST             32783
#define ID_PRIORITY_LOWEST              32784
#define ID_VSYNC                        32785
#define ID_SHOW_TILES                   32786
#define ID_SHOW_MAP                     32787
#define ID_SHOW_DEBUG                   32792
#define ID_SKIP0                        32794
#define ID_SKIP1                        32795
#define ID_SKIP2                        32796
#define ID_SKIP3                        32797
#define ID_SKIP4                        32798
#define ID_SKIP5                        32800
#define ID_LAYER_BG                     32801
#define ID_LAYER_WND                    32802
#define ID_LAYER_OBJ                    32803
#define ID_PALETTE1                     32805
#define ID_PALETTE2                     32806
#define ID_PALETTE3                     32807
#define ID_MENU_DISABLE_ALL             32809
#define ID_SHOW_OAM                     32810
#define VK_CTRL_D                       32812
#define VK_CTRL_M                       32813
#define VK_CTRL_V                       32814
#define VK_CTRL_T                       32815
#define VK_CTRL_S                       32816
#define VK_ALT_1                        32817
#define VK_ALT_2                        32818
#define VK_ALT_3                        32819
#define VK_ALT_4                        32820
#define VK_CTRL_O                       32821
#define VK_CTRL_R                       32822
#define VK_CTRL_X                       32823
#define ID_SOUND_ENABLE                 32824
#define ID_MENU_8BITDIB                 32825
#define ID_MENU_16BITDIB                32826
#define ID_MENUITEM32827                32827
#define ID_MENUITEM32828                32828
#define ID_SOUND_CH1                    32828
#define ID_MENUITEM32829                32829
#define ID_SOUND_CH2                    32829
#define ID_MENUITEM32830                32830
#define ID_SOUND_CH3                    32830
#define ID_MENUITEM32831                32831
#define ID_MENU_KEY                     32832
#define ID_ZOOM1                        32833
#define ID_ZOOM2                        32834
#define ID_ZOOM3                        32835
#define ID_ZOOM4                        32836
#define ID_ZOOM_FULL                    32837
#define ID_FILTER_2XSAI                 32840
#define ID_FILTER_NORMAL                32843
#define ID_FILTER_SUPER2XSAI            32844
#define ID_FILTER_SUPEREAGLE            32845
#define IDM_DMA_DUMP                    32846
#define IDM_STRING_HACK                 32847
#define IDM_CHEAT                       32848
#define IDM_HEADER_INFO                 32849
#define ID_APP_TITLE                    0xE804

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        154
#define _APS_NEXT_COMMAND_VALUE         32850
#define _APS_NEXT_CONTROL_VALUE         1111
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif

==> GameboyVM-Project-0.07.zip: win32/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by GBEmu.rc
//
#define VS_STRING                       1
#define IDS_APP_TITLE                   1
#define IDS_TITLE                       1
#define IDS_UNKNOW_OPCODE               2
#define IDS_UNDEFINE_OPCODE             2
#define IDS_DISASSEMBLING               3
#define IDS_DEBUGGER_TITLE              5
#define IDS_SHOW_FPS                    6
#define IDS_FILTER_ROM                  7
#define IDS_UNSUPPORTED_MMC             8
#define IDS_UNSUPPORTED_GBC             9
#define IDS_INITIALIZE_REGISTERS        10
#define IDS_INITIALIZE_MEMORY           11
#define IDS_FILTER_ALL                  12
#define IDS_UNKNOW_CB_OPCODE            13
#define IDS_UNSUPPORTED_SIZE            14
#define IDS_UNSUPPORTED_ROM_SIZE        14
#define IDS_MEMORY_ALLOC_ERROR          15
#define IDS_NOT_ZIP_FILE                16
#define IDS_ERROR_MAIN_THREAD           17
#define IDD_GBEMU_DIALOG                102
#define IDC_PAINT_CURSOR                104
#define IDR_MAINFRAME                   128
#define IDR_MENU                        129
#define IDC_CURSOR1                     130
#define IDD_KEY_DIALOG                  130
#define IDD_ABOUT_DIALOG                131
#define IDD_TILES_DIALOG                133
#define IDD_MAPS_DIALOG                 135
#define IDD_MEMORY_DIALOG               137
#define IDD_DISASM_DIALOG               139
#define IDD_MEMEDIT_DIALOG              141
#define IDD_OBJ_DIALOG                  141
#define IDR_ACCELERATOR                 145
#define IDC_CURSOR                      149
#define IDD_ABOUT_DIALOG1               150
#define IDD_DISASM_DIALOG1              151
#define IDR_MENU1                       152
#define IDD_DMA_DIALOG                  153
#define IDD_STRINGHACK_DIALOG           154
#define IDC_MAP_ADR1                    1000
#define IDC_MAP_ADR2                    1001
#define IDC_KEY_A                       1001
#define IDC_MEMORY_LIST                 1002
#define IDC_KEY_B                       1002
#define IDC_ADR_CMB                     1003
#define IDC_KEY_S                       1003
#define IDC_DUMP                        1004
#define IDC_KEY_E                       1004
#define IDC_EDIT_ADR                    1005
#define IDC_KEY_U                       1005
#define IDC_KEY_D                       1006
#define IDC_BANK                        1006
#define IDC_GO                          1007
#define IDC_KEY_L                       1007
#define IDC_KEY_R                       1008
#define IDC_DISASM_LIST                 1012
#define IDC_CMD_EDIT                    1013
#define IDC_STACK_LIST                  1014
#define IDC_REG_AF                      1015
#define IDC_REG_BC                      1016
#define IDC_REG_DE                      1017
#define IDC_REG_HL                      1018
#define IDC_REG_SP                      1019
#define IDC_REG_PC                      1020
#define IDC_FLAG_Z                      1021
#define IDC_FLAG_N                      1022
#define IDC_FLAG_H                      1023
#define IDC_FLAG_C                      1024
#define IDC_FLAG_IME                    1025
#define IDC_BREAK_POINT1                1029
#define IDC_BREAK_POINT2                1030
#define IDC_NEXT                        1031
#define IDC_EDIT2                       1032
#define IDC_EDIT_GOTO                   1032
#define IDC_BREAK_POINT3                1033
#define IDC_CHECK2                      1034
#define IDC_INTERRUPT1                  1034
#define IDC_CHECK_OBJ1                  1034
#define IDC_CHECK3                      1035
#define IDC_INTERRUPT2                  1035
#define IDC_CHECK_OBJ2                  1035
#define IDC_CHECK4                      1036
#define IDC_INTERRUPT3                  1036
#define IDC_CHECK_OBJ4                  1036
#define IDC_CHECK5                      1037
#define IDC_INTERRUPT4                  1037
#define IDC_CHECK_OBJ3                  1037
#define IDC_CHECK6                      1038
#define IDC_INTERRUPT5                  1038
#define IDC_CHECK7                      1041
#define IDC_CHECK_BREAK                 1041
#define IDC_BUTTON4                     1043
#define IDC_RUN                         1043
#define IDC_RESET                       1044
#define IDC_STOP                        1045
#define IDC_GOTO                        1050
#define IDC_URL                         1051
#define IDC_OBJ_NO                      1054
#define IDC_OBJ_POSITION                1055
#define IDC_OBJ_RETURN                  1056
#define IDC_OBJ_TILENO                  1057
#define IDC_OBJ_NEXT                    1058
#define IDC_OBJ_SIZE                    1059
#define IDC_GROUP_LCDC                  1061
#define IDC_GROUP_BGP                   1062
#define IDC_MEM_SCROLLBAR               1063
#define IDC_GROUP_CGB                   1063
#define IDC_Update                      1064
#define ID_CMD_OK                       1065
#define IDC_GROUP_STATUS                1066
#define IDC_TILE_ADDRESS                1068
#define IDC_STATIC_ADDRESS              1069
#define IDC_TILE_NO                     1070
#define IDC_STATIC_NO                   1071
#define IDC_MODE_FLAG                   1072
#define IDC_STATIC_BANK                 1073
#define IDC_SCROLLBAR_DMA               1074
#define IDC_DMA_ADDRESS                 1075
#define IDC_BUTTON_GO                   1076
#define IDC_CHECK_EDIT                  1080
#define IDC_IMAGE_CHAR                  1081
#define IDC_IMAGE_TILES                 1082
#define IDC_BUTTON_SAVE                 1094
#define IDC_EDIT_OFFSET                 1095
#define IDC_BUTTON_RESET                1096
#define IDC_BUTTON_WRITE                1100
#define IDC_SCROLLBAR_BANK              1101
#define IDC_PALETTE0                    1102
#define IDC_EDIT_BANK                   1103
#define IDC_BUTTON_SAVEBIN              1104
#define IDC_BUTTON_LOADBIN              1105
#define IDC_PALETTE1                    1106
#define IDC_PALETTE2                    1107
#define IDC_PALETTE3                    1108
#define IDC_STATIC_OFFSET               1109
#define IDC_STRING_BOX                  1111
#define ID_MENU_OPEN                    32771
#define ID_MENU_EXIT                    32772
#define ID_MENU_ABOUT                   32773
#define ID_MENU_RESET                   32774
#define ID_SHOW_FPS                     32775
#define ID_SHOW_MEMORY                  32776
#define ID_PRIORITY_NORMAL              32779
#define ID_PRIORITY_ABOVE               32781
#define ID_PRIORITY_BELOW               32782
#define ID_PRIORITY_HIGHEST             32783
#define ID_PRIORITY_LOWEST              32784
#define ID_VSYNC                        32785
#define ID_SHOW_TILES                   32786
#define ID_SHOW_MAP                     32787
#define ID_SHOW_DEBUG                   32792
#define ID_SKIP0                        32794
#define ID_SKIP1                        32795
#define ID_SKIP2                        32796
#define ID_SKIP3                        32797
#define ID_SKIP4                        32798
#define ID_SKIP5                        32800
#define ID_LAYER_BG                     32801
#define ID_LAYER_WND                    32802
#define ID_LAYER_OBJ                    32803
#define ID_PALETTE1                     32805
#define ID_PALETTE2                     32806
#define ID_PALETTE3                     32807
#define ID_MENU_DISABLE_ALL             32809
#define ID_SHOW_OAM                     32810
#define VK_CTRL_D                       32812
#define VK_CTRL_M                       32813
#define VK_CTRL_V                       32814
#define VK_CTRL_T                       32815
#define VK_CTRL_S                       32816
#define VK_ALT_1                        32817
#define VK_ALT_2                        32818
#define VK_ALT_3                        32819
#define VK_ALT_4                        32820
#define VK_CTRL_O                       32821
#define VK_CTRL_R                       32822
#define VK_CTRL_X                       32823
#define ID_SOUND_ENABLE                 32824
#define ID_MENU_8BITDIB                 32825
#define ID_MENU_16BITDIB                32826
#define ID_MENUITEM32827                32827
#define ID_MENUITEM32828                32828
#define ID_SOUND_CH1                    32828
#define ID_MENUITEM32829                32829
#define ID_SOUND_CH2                    32829
#define ID_MENUITEM32830                32830
#define ID_SOUND_CH3                    32830
#define ID_MENUITEM32831                32831
#define ID_MENU_KEY                     32832
#define ID_ZOOM1                        32833
#define ID_ZOOM2                        32834
#define ID_ZOOM3                        32835
#define ID_ZOOM4                        32836
#define ID_ZOOM_FULL                    32837
#define ID_FILTER_2XSAI                 32840
#define ID_FILTER_NORMAL                32843
#define ID_FILTER_SUPER2XSAI            32844
#define ID_FILTER_SUPEREAGLE            32845
#define IDM_DMA_DUMP                    32846
#define IDM_STRING_HACK                 32847
#define IDM_CHEAT                       32848
#define IDM_HEADER_INFO                 32849
#define ID_FILTER_PIXELATE              32850
#define ID_FILTER_MOTIONBLUR            32851
#define ID_FILTER_TVMODE                32852
#define IDM_AUTO_SAVE                   32853
#define IDM_AUTO_LOAD                   32854
#define IDM_SAVE                        32855
#define IDM_LOAD                        32856
#define IDM_MODE_COLOR                  32857
#define IDM_MODE_POCKET                 32858
#define IDM_CLASSIC                     32859
#define IDM_MODE_AUTO                   32860
#define ID_APP_TITLE                    0xE804

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        155
#define _APS_NEXT_COMMAND_VALUE         32861
#define _APS_NEXT_CONTROL_VALUE         1112
#define _APS_NEXT_SYMED_VALUE           101
#endif
#endif
